@@ -239,7 +239,16 @@ def catalog_info() -> dict[str, Any]:
     """Get information about the current Quilt catalog configuration.
 
     Returns:
-        Dict with catalog name, URLs, authentication status, and configuration details.
+        Dict with the following keys (keys present only if values are set):
+        - catalog_name: Catalog name (always present)
+        - is_authenticated: Boolean authentication status (always present)
+        - status: Operation status (always present)
+        - navigator_url: Navigator URL (if configured)
+        - registry_url: Registry URL (if configured)
+        - logged_in_url: Login URL (if authenticated)
+        - region: AWS region (if authenticated and available)
+        - tabulator_data_catalog: Tabulator catalog name (if authenticated and available)
+        - message: Contextual message (always present)
     """
     try:
         info = _get_catalog_info()
@@ -258,6 +267,12 @@ def catalog_info() -> dict[str, Any]:
         if info["logged_in_url"]:
             result["logged_in_url"] = info["logged_in_url"]
 
+        # Add AWS region and tabulator catalog if authenticated
+        if info["region"]:
+            result["region"] = info["region"]
+        if info["tabulator_data_catalog"]:
+            result["tabulator_data_catalog"] = info["tabulator_data_catalog"]
+
         # Add helpful context
         if info["is_authenticated"]:
             result["message"] = f"Connected to catalog: {info['catalog_name']}"
